@@ -4,6 +4,7 @@ set -o errexit  # Exit the script with error if any of the commands fail
 # Supported/used environment variables:
 # Options for this script:
 #       CFLAGS                  Additional compiler flags
+#       C_STD_VERSION           C standard version to compile with (default: 99)
 #       MARCH                   Machine Architecture. Defaults to lowercase uname -m
 #       RELEASE                 Use the fully qualified release archive
 #       DEBUG                   Use debug configure flags
@@ -28,6 +29,7 @@ set -o errexit  # Exit the script with error if any of the commands fail
 #       ZSTD                    Build against system zstd.
 
 # Options for this script.
+C_STD_VERSION=${CSTD_VERSION:-99}
 RELEASE=${RELEASE:-OFF}
 DEBUG=${DEBUG:-OFF}
 TRACING=${TRACING:-OFF}
@@ -46,6 +48,7 @@ ZLIB=${ZLIB:-BUNDLED}
 INSTALL_DIR=$(pwd)/install-dir
 
 echo "CFLAGS: $CFLAGS"
+echo "C_STD_VERSION: $C_STD_VERSION"
 echo "SANITIZE: $SANITIZE"
 echo "MARCH: $MARCH"
 echo "RELEASE: $RELEASE"
@@ -163,6 +166,8 @@ export ASAN_OPTIONS="detect_leaks=1 abort_on_error=1 symbolize=1"
 export ASAN_SYMBOLIZER_PATH="/opt/mongodbtoolchain/v3/bin/llvm-symbolizer"
 export TSAN_OPTIONS="suppressions=./.tsan-suppressions"
 
+CONFIGURE_FLAGS="$CONFIGURE_FLAGS -DCMAKE_C_STANDARD=$C_STD_VERSION -DCMAKE_C_STANDARD_REQUIRED=ON -DCMAKE_C_EXTENSIONS=OFF"
+
 case "$MARCH" in
    i386)
       CFLAGS="$CFLAGS -m32 -march=i386"
@@ -259,6 +264,11 @@ if [ "$ANALYZE" = "ON" ]; then
    else
       SCAN_BUILD_COMMAND="scan-build-3.9"
    fi
+
+   # Do not include bundled zlib in scan-build analysis.
+   # scan-build `--exclude`` flag is not available on all Evergreen variants.
+   CONFIGURE_FLAGS="$CONFIGURE_FLAGS -DENABLE_ZLIB=OFF"
+
    $SCAN_BUILD_COMMAND $CMAKE $CONFIGURE_FLAGS .
 
    # Put clang static analyzer results in scan/ and fail build if warnings found.
