@@ -51,24 +51,21 @@ typedef uint32_t bson_unichar_t;
 
 
 /**
- * bson_context_flags_t:
- *
- * This enumeration is used to configure a bson_context_t.
- *
- * %BSON_CONTEXT_NONE: Use default options.
- * %BSON_CONTEXT_THREAD_SAFE: Context will be called from multiple threads.
- * %BSON_CONTEXT_DISABLE_HOST_CACHE: Does nothing, is ignored.
- * %BSON_CONTEXT_DISABLE_PID_CACHE: Call getpid() instead of caching the
- *   result of getpid() when initializing the context.
+ * @brief Flags configuring the creation of a bson_context_t
  */
 typedef enum {
+   /** Use default options */
    BSON_CONTEXT_NONE = 0,
+   /* Deprecated: Generating new OIDs from a bson_context_t is always
+      thread-safe */
    BSON_CONTEXT_THREAD_SAFE = (1 << 0),
+   /* Deprecated: Does nothing and is ignored */
    BSON_CONTEXT_DISABLE_HOST_CACHE = (1 << 1),
+   /* Call getpid() instead of remembering the result of getpid() when using the
+      context */
    BSON_CONTEXT_DISABLE_PID_CACHE = (1 << 2),
-#ifdef BSON_HAVE_SYSCALL_TID
+   /* Deprecated: Does nothing */
    BSON_CONTEXT_USE_TASK_ID = (1 << 3),
-#endif
 } bson_context_flags_t;
 
 
@@ -97,6 +94,17 @@ typedef enum {
  */
 typedef struct _bson_context_t bson_context_t;
 
+/**
+ * bson_json_opts_t:
+ *
+ * This structure is used to pass options for serializing BSON into extended
+ * JSON to the respective serialization methods.
+ *
+ * max_len can be either a non-negative integer, or BSON_MAX_LEN_UNLIMITED to
+ * set no limit for serialization length.
+ */
+typedef struct _bson_json_opts_t bson_json_opts_t;
+
 
 /**
  * bson_t:
@@ -116,23 +124,20 @@ typedef struct _bson_context_t bson_context_t;
  * This structure is meant to fit in two sequential 64-byte cachelines.
  */
 #ifdef BSON_MEMCHECK
-BSON_ALIGNED_BEGIN (128)
-typedef struct _bson_t {
-   uint32_t flags;       /* Internal flags for the bson_t. */
-   uint32_t len;         /* Length of BSON data. */
-   char *canary;         /* For valgrind check */
-   uint8_t padding[120 - sizeof (char*)];
+BSON_ALIGNED_BEGIN (128) typedef struct _bson_t {
+   uint32_t flags; /* Internal flags for the bson_t. */
+   uint32_t len;   /* Length of BSON data. */
+   char *canary;   /* For valgrind check */
+   uint8_t padding[120 - sizeof (char *)];
 } bson_t BSON_ALIGNED_END (128);
 #else
-BSON_ALIGNED_BEGIN (128)
-typedef struct _bson_t {
+BSON_ALIGNED_BEGIN (128) typedef struct _bson_t {
    uint32_t flags;       /* Internal flags for the bson_t. */
    uint32_t len;         /* Length of BSON data. */
    uint8_t padding[120]; /* Padding for stack allocation. */
 } bson_t BSON_ALIGNED_END (128);
 #endif
 
-
 /**
  * BSON_INITIALIZER:
  *
@@ -144,13 +149,9 @@ typedef struct _bson_t {
  * ]|
  */
 #ifdef BSON_MEMCHECK
-#define BSON_INITIALIZER \
-   {                     \
-      3, 5,              \
-      bson_malloc (1),   \
-      {                  \
-         5               \
-      },                 \
+#define BSON_INITIALIZER          \
+   {                              \
+      3, 5, bson_malloc (1), {5}, \
    }
 #else
 #define BSON_INITIALIZER \
@@ -271,6 +272,7 @@ typedef enum {
    BSON_SUBTYPE_UUID = 0x04,
    BSON_SUBTYPE_MD5 = 0x05,
    BSON_SUBTYPE_ENCRYPTED = 0x06,
+   BSON_SUBTYPE_COLUMN = 0x07,
    BSON_SUBTYPE_USER = 0x80,
 } bson_subtype_t;
 
