@@ -41,9 +41,11 @@
 
 BSON_BEGIN_DECLS
 
-/* protocol versions this driver can speak */
-#define WIRE_VERSION_MIN 3
-#define WIRE_VERSION_MAX 9
+/* Range of wire protocol versions this driver supports. Bumping
+ * WIRE_VERSION_MAX must be accompanied by an update to
+ * `_mongoc_wire_version_to_server_version`. */
+#define WIRE_VERSION_MIN 6  /* a.k.a. minWireVersion */
+#define WIRE_VERSION_MAX 17 /* a.k.a. maxWireVersion */
 
 /* first version that supported "find" and "getMore" commands */
 #define WIRE_VERSION_FIND_CMD 4
@@ -90,6 +92,14 @@ BSON_BEGIN_DECLS
 #define WIRE_VERSION_RETRYABLE_WRITE_ERROR_LABEL 9
 /* first version to support server hedged reads */
 #define WIRE_VERSION_HEDGED_READS 9
+/* first version to support estimatedDocumentCount with collStats */
+#define WIRE_VERSION_4_9 12
+/* version corresponding to server 5.0 release */
+#define WIRE_VERSION_5_0 13
+/* first version to support snapshot reads */
+#define WIRE_VERSION_SNAPSHOT_READS 13
+/* version corresponding to server 5.1 release */
+#define WIRE_VERSION_5_1 14
 
 struct _mongoc_collection_t;
 
@@ -97,6 +107,7 @@ struct _mongoc_client_t {
    mongoc_uri_t *uri;
    mongoc_cluster_t cluster;
    bool in_exhaust;
+   bool is_pooled;
 
    mongoc_stream_initiator_t initiator;
    void *initiator_data;
@@ -118,6 +129,8 @@ struct _mongoc_client_t {
    int32_t error_api_version;
    bool error_api_set;
 
+   mongoc_server_api_t *api;
+
    /* mongoc_client_session_t's in use, to look up lsids and clusterTimes */
    mongoc_set_t *client_sessions;
    unsigned int csid_rand_seed;
@@ -139,32 +152,20 @@ typedef enum {
 BSON_STATIC_ASSERT2 (mongoc_cmd_rw,
                      MONGOC_CMD_RW == (MONGOC_CMD_READ | MONGOC_CMD_WRITE));
 
-typedef enum { MONGOC_RR_SRV, MONGOC_RR_TXT } mongoc_rr_type_t;
-
-typedef struct _mongoc_rr_data_t {
-   /* Number of records returned by DNS. */
-   uint32_t count;
-
-   /* Set to lowest TTL found when polling SRV records. */
-   uint32_t min_ttl;
-
-   /* Set to the resulting host list when polling SRV records */
-   mongoc_host_list_t *hosts;
-
-   /* Set to the TXT record when polling for TXT */
-   char *txt_record_opts;
-} mongoc_rr_data_t;
 
+/* TODO (CDRIVER-4052): Move MONGOC_RR_DEFAULT_BUFFER_SIZE and
+ * _mongoc_client_get_rr to mongoc-topology-private.h or in a separate file.
+ * There is no reason these should be in mongoc-client. */
 #define MONGOC_RR_DEFAULT_BUFFER_SIZE 1024
 bool
-_mongoc_client_get_rr (const char *service,
+_mongoc_client_get_rr (const char *hostname,
                        mongoc_rr_type_t rr_type,
                        mongoc_rr_data_t *rr_data,
                        size_t initial_buffer_size,
                        bson_error_t *error);
 
 mongoc_client_t *
-_mongoc_client_new_from_uri (mongoc_topology_t *topology);
+_mongoc_client_new_from_topology (mongoc_topology_t *topology);
 
 bool
 _mongoc_client_set_apm_callbacks_private (mongoc_client_t *client,
@@ -243,6 +244,13 @@ mongoc_client_connect (bool buffered,
                        const mongoc_uri_t *uri,
                        const mongoc_host_list_t *host,
                        bson_error_t *error);
+
+
+/* Returns true if a versioned server API has been selected,
+ * otherwise returns false. */
+bool
+mongoc_client_uses_server_api (const mongoc_client_t *client);
+
 BSON_END_DECLS
 
 #endif /* MONGOC_CLIENT_PRIVATE_H */
