@@ -45,9 +45,20 @@ struct _mongoc_auto_encryption_opts_t {
    bson_t *encrypted_fields_map;
    bool bypass_auto_encryption;
    bool bypass_query_analysis;
+   mc_kms_credentials_callback creds_cb;
    bson_t *extra;
 };
 
+static void
+_set_creds_callback (mc_kms_credentials_callback *cb,
+                     mongoc_kms_credentials_provider_callback_fn fn,
+                     void *userdata)
+{
+   BSON_ASSERT (cb);
+   cb->fn = fn;
+   cb->userdata = userdata;
+}
+
 mongoc_auto_encryption_opts_t *
 mongoc_auto_encryption_opts_new (void)
 {
@@ -206,6 +217,15 @@ mongoc_auto_encryption_opts_set_extra (mongoc_auto_encryption_opts_t *opts,
    }
 }
 
+void
+mongoc_auto_encryption_opts_set_kms_credential_provider_callback (
+   mongoc_auto_encryption_opts_t *opts,
+   mongoc_kms_credentials_provider_callback_fn fn,
+   void *userdata)
+{
+   _set_creds_callback (&opts->creds_cb, fn, userdata);
+}
+
 /*--------------------------------------------------------------------------
  * Client Encryption options.
  *--------------------------------------------------------------------------
@@ -216,6 +236,7 @@ struct _mongoc_client_encryption_opts_t {
    char *keyvault_coll;
    bson_t *kms_providers;
    bson_t *tls_opts;
+   mc_kms_credentials_callback creds_cb;
 };
 
 mongoc_client_encryption_opts_t *
@@ -230,6 +251,7 @@ mongoc_client_encryption_opts_destroy (mongoc_client_encryption_opts_t *opts)
    if (!opts) {
       return;
    }
+   _set_creds_callback (&opts->creds_cb, NULL, NULL);
    bson_free (opts->keyvault_db);
    bson_free (opts->keyvault_coll);
    bson_destroy (opts->kms_providers);
@@ -287,6 +309,17 @@ mongoc_client_encryption_opts_set_tls_opts (
    opts->tls_opts = _bson_copy_or_null (tls_opts);
 }
 
+void
+mongoc_client_encryption_opts_set_kms_credential_provider_callback (
+   mongoc_client_encryption_opts_t *opts,
+   mongoc_kms_credentials_provider_callback_fn fn,
+   void *userdata)
+{
+   BSON_ASSERT_PARAM (opts);
+   opts->creds_cb.fn = fn;
+   opts->creds_cb.userdata = userdata;
+}
+
 /*--------------------------------------------------------------------------
  * Data key options.
  *--------------------------------------------------------------------------
@@ -500,8 +533,8 @@ mongoc_client_encryption_rewrap_many_datakey_result_t *
 mongoc_client_encryption_rewrap_many_datakey_result_new (void)
 {
    mongoc_client_encryption_rewrap_many_datakey_result_t *const res =
-      bson_malloc0 (
-         sizeof (mongoc_client_encryption_rewrap_many_datakey_result_t));
+      BSON_ALIGNED_ALLOC0 (
+         mongoc_client_encryption_rewrap_many_datakey_result_t);
 
    bson_init (&res->bulk_write_result);
 
@@ -558,6 +591,10 @@ _mongoc_cse_auto_encrypt (mongoc_client_t *client,
                           bson_t *encrypted,
                           bson_error_t *error)
 {
+   BSON_UNUSED (client);
+   BSON_UNUSED (cmd);
+   BSON_UNUSED (encrypted_cmd);
+
    bson_init (encrypted);
 
    return _disabled_error (error);
@@ -570,7 +607,12 @@ _mongoc_cse_auto_decrypt (mongoc_client_t *client,
                           bson_t *decrypted,
                           bson_error_t *error)
 {
+   BSON_UNUSED (client);
+   BSON_UNUSED (db_name);
+   BSON_UNUSED (reply);
+
    bson_init (decrypted);
+
    return _disabled_error (error);
 }
 
@@ -580,6 +622,9 @@ _mongoc_cse_client_enable_auto_encryption (
    mongoc_auto_encryption_opts_t *opts /* may be NULL */,
    bson_error_t *error)
 {
+   BSON_UNUSED (client);
+   BSON_UNUSED (opts);
+
    return _disabled_error (error);
 }
 
@@ -589,6 +634,9 @@ _mongoc_cse_client_pool_enable_auto_encryption (
    mongoc_auto_encryption_opts_t *opts /* may be NULL */,
    bson_error_t *error)
 {
+   BSON_UNUSED (topology);
+   BSON_UNUSED (opts);
+
    return _disabled_error (error);
 }
 
@@ -601,9 +649,14 @@ mongoc_client_encryption_create_datakey (
    bson_value_t *keyid,
    bson_error_t *error)
 {
+   BSON_UNUSED (client_encryption);
+   BSON_UNUSED (kms_provider);
+   BSON_UNUSED (opts);
+
    if (keyid) {
       memset (keyid, 0, sizeof (*keyid));
    }
+
    return _disabled_error (error);
 }
 
@@ -617,6 +670,12 @@ mongoc_client_encryption_rewrap_many_datakey (
    mongoc_client_encryption_rewrap_many_datakey_result_t *result,
    bson_error_t *error)
 {
+   BSON_UNUSED (client_encryption);
+   BSON_UNUSED (filter);
+   BSON_UNUSED (provider);
+   BSON_UNUSED (master_key);
+   BSON_UNUSED (result);
+
    return _disabled_error (error);
 }
 
@@ -628,7 +687,11 @@ mongoc_client_encryption_delete_key (
    bson_t *reply,
    bson_error_t *error)
 {
+   BSON_UNUSED (client_encryption);
+   BSON_UNUSED (keyid);
+
    _mongoc_bson_init_if_set (reply);
+
    return _disabled_error (error);
 }
 
@@ -639,7 +702,11 @@ mongoc_client_encryption_get_key (mongoc_client_encryption_t *client_encryption,
                                   bson_t *key_doc,
                                   bson_error_t *error)
 {
+   BSON_UNUSED (client_encryption);
+   BSON_UNUSED (keyid);
+
    _mongoc_bson_init_if_set (key_doc);
+
    return _disabled_error (error);
 }
 
@@ -648,7 +715,10 @@ mongoc_cursor_t *
 mongoc_client_encryption_get_keys (
    mongoc_client_encryption_t *client_encryption, bson_error_t *error)
 {
+   BSON_UNUSED (client_encryption);
+
    _disabled_error (error);
+
    return NULL;
 }
 
@@ -661,7 +731,12 @@ mongoc_client_encryption_add_key_alt_name (
    bson_t *key_doc,
    bson_error_t *error)
 {
+   BSON_UNUSED (client_encryption);
+   BSON_UNUSED (keyid);
+   BSON_UNUSED (keyaltname);
+
    _mongoc_bson_init_if_set (key_doc);
+
    return _disabled_error (error);
 }
 
@@ -674,7 +749,12 @@ mongoc_client_encryption_remove_key_alt_name (
    bson_t *key_doc,
    bson_error_t *error)
 {
+   BSON_UNUSED (client_encryption);
+   BSON_UNUSED (keyid);
+   BSON_UNUSED (keyaltname);
+
    _mongoc_bson_init_if_set (key_doc);
+
    return _disabled_error (error);
 }
 
@@ -686,7 +766,11 @@ mongoc_client_encryption_get_key_by_alt_name (
    bson_t *key_doc,
    bson_error_t *error)
 {
+   BSON_UNUSED (client_encryption);
+   BSON_UNUSED (keyaltname);
+
    _mongoc_bson_init_if_set (key_doc);
+
    return _disabled_error (error);
 }
 
@@ -695,13 +779,17 @@ MONGOC_EXPORT (mongoc_client_encryption_t *)
 mongoc_client_encryption_new (mongoc_client_encryption_opts_t *opts,
                               bson_error_t *error)
 {
+   BSON_UNUSED (opts);
+
    _disabled_error (error);
+
    return NULL;
 }
 
 void
 mongoc_client_encryption_destroy (mongoc_client_encryption_t *client_encryption)
 {
+   BSON_UNUSED (client_encryption);
 }
 
 bool
@@ -711,9 +799,14 @@ mongoc_client_encryption_encrypt (mongoc_client_encryption_t *client_encryption,
                                   bson_value_t *ciphertext,
                                   bson_error_t *error)
 {
+   BSON_UNUSED (client_encryption);
+   BSON_UNUSED (value);
+   BSON_UNUSED (opts);
+
    if (ciphertext) {
       memset (ciphertext, 0, sizeof (*ciphertext));
    }
+
    return _disabled_error (error);
 }
 
@@ -723,15 +816,21 @@ mongoc_client_encryption_decrypt (mongoc_client_encryption_t *client_encryption,
                                   bson_value_t *value,
                                   bson_error_t *error)
 {
+   BSON_UNUSED (client_encryption);
+   BSON_UNUSED (ciphertext);
+
    if (value) {
       memset (value, 0, sizeof (*value));
    }
+
    return _disabled_error (error);
 }
 
 bool
 _mongoc_cse_is_enabled (mongoc_client_t *client)
 {
+   BSON_UNUSED (client);
+
    return false;
 }
 
@@ -1018,6 +1117,8 @@ _mongoc_cse_auto_decrypt (mongoc_client_t *client_encrypted,
 
    ENTRY;
 
+   BSON_UNUSED (db_name);
+
    keyvault_coll = _get_keyvault_coll (client_encrypted);
    if (!_mongoc_crypt_auto_decrypt (client_encrypted->topology->crypt,
                                     keyvault_coll,
@@ -1551,16 +1652,20 @@ _mongoc_cse_client_enable_auto_encryption (mongoc_client_t *client,
                             .extraOptions.cryptSharedLibRequired,
                          opts->bypass_auto_encryption,
                          opts->bypass_query_analysis,
+                         opts->creds_cb,
                          error);
    if (!client->topology->crypt) {
       GOTO (fail);
    }
 
+   const bool have_crypt_shared =
+      _mongoc_crypt_get_crypt_shared_version (client->topology->crypt) != NULL;
+
    client->topology->bypass_auto_encryption = opts->bypass_auto_encryption;
    client->topology->bypass_query_analysis = opts->bypass_query_analysis;
 
    if (!client->topology->bypass_auto_encryption &&
-       !client->topology->bypass_query_analysis) {
+       !client->topology->bypass_query_analysis && !have_crypt_shared) {
       if (!client->topology->mongocryptd_bypass_spawn) {
          if (!_spawn_mongocryptd (client->topology->mongocryptd_spawn_path,
                                   client->topology->mongocryptd_spawn_args,
@@ -1712,6 +1817,7 @@ _mongoc_cse_client_pool_enable_auto_encryption (
                             .cryptSharedLibRequired,
                          opts->bypass_auto_encryption,
                          opts->bypass_query_analysis,
+                         opts->creds_cb,
                          error);
    if (!topology->crypt) {
       GOTO (fail);
@@ -1817,11 +1923,14 @@ mongoc_client_encryption_new (mongoc_client_encryption_opts_t *opts,
                          NULL /* No crypt_shared path */,
                          false /* crypt_shared not requried */,
                          true, /* bypassAutoEncryption (We are explicit) */
-                         false /* bypass_query_analysis. Not applicable. */,
+                         false,
+                         /* bypass_query_analysis. Not applicable. */
+                         opts->creds_cb,
                          error);
    if (!client_encryption->crypt) {
       goto fail;
    }
+
    success = true;
 
 fail:
@@ -2209,6 +2318,8 @@ mongoc_client_encryption_get_keys (
 
    ENTRY;
 
+   BSON_UNUSED (error);
+
    BSON_ASSERT_PARAM (client_encryption);
 
    BSON_ASSERT (
@@ -2562,3 +2673,30 @@ _mongoc_cse_is_enabled (mongoc_client_t *client)
 }
 
 #endif /* MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION */
+
+
+const char *
+mongoc_client_encryption_get_crypt_shared_version (
+   const mongoc_client_encryption_t *enc)
+{
+#ifdef MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION
+   return _mongoc_crypt_get_crypt_shared_version (enc->crypt);
+#else
+   BSON_UNUSED (enc);
+   return NULL;
+#endif
+}
+
+const char *
+mongoc_client_get_crypt_shared_version (const mongoc_client_t *const client)
+{
+#ifdef MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION
+   if (!client->topology->crypt) {
+      return NULL;
+   }
+   return _mongoc_crypt_get_crypt_shared_version (client->topology->crypt);
+#else
+   BSON_UNUSED (client);
+   return NULL;
+#endif
+}
