@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-prelude.h"
+#include "mongoc-prelude.h"
 
 
 /*
@@ -29,13 +29,22 @@
 
 #include <bson/bson.h>
 
-#include "mongoc/mongoc-server-stream-private.h"
-#include "mongoc/mongoc-read-prefs.h"
-#include "mongoc/mongoc.h"
-#include "mongoc/mongoc-opts-private.h"
+#include "mongoc-server-api.h"
+#include "mongoc-server-stream-private.h"
+#include "mongoc-read-prefs.h"
+#include "mongoc.h"
+#include "mongoc-opts-private.h"
 
 BSON_BEGIN_DECLS
 
+#define MONGOC_DEFAULT_RETRYREADS true
+/* retryWrites requires sessions, which require crypto */
+#ifdef MONGOC_ENABLE_CRYPTO
+#define MONGOC_DEFAULT_RETRYWRITES true
+#else
+#define MONGOC_DEFAULT_RETRYWRITES false
+#endif
+
 typedef enum {
    MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_UNKNOWN,
    MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_YES,
@@ -50,9 +59,10 @@ typedef struct _mongoc_cmd_t {
    const uint8_t *payload;
    int32_t payload_size;
    const char *payload_identifier;
-   const mongoc_server_stream_t *server_stream;
+   mongoc_server_stream_t *server_stream;
    int64_t operation_id;
    mongoc_client_session_t *session;
+   mongoc_server_api_t *api;
    bool is_acknowledged;
    bool is_txn_finish;
 } mongoc_cmd_t;
@@ -71,9 +81,11 @@ typedef struct _mongoc_cmd_parts_t {
    bool is_write_command;
    bool prohibit_lsid;
    mongoc_cmd_parts_allow_txn_number_t allow_txn_number;
+   bool is_retryable_read;
    bool is_retryable_write;
    bool has_temp_session;
    mongoc_client_t *client;
+   mongoc_server_api_t *api;
 } mongoc_cmd_parts_t;
 
 
@@ -88,6 +100,10 @@ void
 mongoc_cmd_parts_set_session (mongoc_cmd_parts_t *parts,
                               mongoc_client_session_t *cs);
 
+void
+mongoc_cmd_parts_set_server_api (mongoc_cmd_parts_t *parts,
+                                 mongoc_server_api_t *api);
+
 bool
 mongoc_cmd_parts_append_opts (mongoc_cmd_parts_t *parts,
                               bson_iter_t *iter,
@@ -114,7 +130,7 @@ mongoc_cmd_parts_append_read_write (mongoc_cmd_parts_t *parts,
 
 bool
 mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts,
-                           const mongoc_server_stream_t *server_stream,
+                           mongoc_server_stream_t *server_stream,
                            bson_error_t *error);
 
 bool
@@ -123,6 +139,17 @@ mongoc_cmd_is_compressible (mongoc_cmd_t *cmd);
 void
 mongoc_cmd_parts_cleanup (mongoc_cmd_parts_t *op);
 
+bool
+_is_retryable_read (const mongoc_cmd_parts_t *parts,
+                    const mongoc_server_stream_t *server_stream);
+
+void
+_mongoc_cmd_append_payload_as_array (const mongoc_cmd_t *cmd, bson_t *out);
+
+void
+_mongoc_cmd_append_server_api (bson_t *command_body,
+                               const mongoc_server_api_t *api);
+
 BSON_END_DECLS
 
 
