@@ -62,6 +62,9 @@ _mongoc_cursor_monitor_legacy_get_more (mongoc_cursor_t *cursor,
                                     cursor->operation_id,
                                     &server_stream->sd->host,
                                     server_stream->sd->id,
+                                    &server_stream->sd->service_id,
+                                    server_stream->sd->server_connection_id,
+                                    NULL,
                                     client->apm_context);
 
    client->apm_callbacks.started (&event);
@@ -476,9 +479,9 @@ _mongoc_cursor_op_query_find (mongoc_cursor_t *cursor,
    started = bson_get_monotonic_time ();
 
    /* When the user explicitly provides a readConcern -- but the server
-       * doesn't support readConcern, we must error:
-       * https://github.com/mongodb/specifications/blob/master/source/read-write-concern/read-write-concern.rst#errors-1
-       */
+    * doesn't support readConcern, we must error:
+    * https://github.com/mongodb/specifications/blob/master/source/read-write-concern/read-write-concern.rst#errors-1
+    */
    if (cursor->read_concern->level != NULL &&
        server_stream->sd->max_wire_version < WIRE_VERSION_READ_CONCERN) {
       bson_set_error (&cursor->error,
