@@ -29,6 +29,7 @@
 #include "mongoc-log.h"
 #include "mongoc-secure-transport-private.h"
 #include "mongoc-ssl.h"
+#include "mongoc-ssl-private.h"
 #include "mongoc-error.h"
 #include "mongoc-counters-private.h"
 #include "mongoc-stream-tls.h"
@@ -317,23 +318,22 @@ _mongoc_stream_tls_secure_transport_readv (mongoc_stream_t *stream,
       iov_pos = 0;
 
       while (iov_pos < iov[i].iov_len) {
+         remaining_buf_size = iov[i].iov_len - iov_pos;
+         remaining_to_read = min_bytes - ret;
 
-	 remaining_buf_size = iov[i].iov_len - iov_pos;
-	 remaining_to_read = min_bytes - ret;
-
-	 /* The third argument passed to SSLRead is an all-or-nothing
-	    dataLength, which it will attempt to read until it succeeds or
-	    times out. If our buffer is larger than the message we expect
-	    to read, choose the smaller number of the two. */
-	 if (remaining_to_read > 0 && remaining_to_read < remaining_buf_size) {
-	    to_read = remaining_to_read;
-	 } else {
-	    to_read = remaining_buf_size;
-	 }
+         /* The third argument passed to SSLRead is an all-or-nothing
+            dataLength, which it will attempt to read until it succeeds or
+            times out. If our buffer is larger than the message we expect
+            to read, choose the smaller number of the two. */
+         if (remaining_to_read > 0 && remaining_to_read < remaining_buf_size) {
+            to_read = remaining_to_read;
+         } else {
+            to_read = remaining_buf_size;
+         }
 
          OSStatus status = SSLRead (secure_transport->ssl_ctx_ref,
                                     (char *) iov[i].iov_base + iov_pos,
-				    to_read,
+                                    to_read,
                                     &read_ret);
 
          if (status != noErr) {
@@ -417,6 +417,184 @@ _mongoc_stream_tls_secure_transport_check_closed (
    RETURN (mongoc_stream_check_closed (tls->base_stream));
 }
 
+static void
+_set_error_from_osstatus (OSStatus status,
+                          const char *prefix,
+                          bson_error_t *error)
+{
+   CFStringRef err;
+   char *err_str;
+
+   err = SecCopyErrorMessageString (status, NULL);
+   err_str = _mongoc_cfstringref_to_cstring (err);
+   bson_set_error (error,
+                   MONGOC_ERROR_STREAM,
+                   MONGOC_ERROR_STREAM_SOCKET,
+                   "%s: %s (%d)",
+                   prefix,
+                   err_str,
+                   status);
+
+   bson_free (err_str);
+   CFRelease (err);
+}
+
+/* Always returns a string that must be freed. */
+static char *
+explain_trust_result (SecTrustRef trust, SecTrustResultType trust_result)
+{
+   bson_string_t *reason;
+   CFArrayRef cfprops = NULL;
+   CFIndex count, i;
+
+   reason = bson_string_new ("");
+   switch (trust_result) {
+   case kSecTrustResultDeny:
+      bson_string_append (reason, "Certificate trust denied");
+      break;
+   case kSecTrustResultRecoverableTrustFailure:
+      bson_string_append (reason, "Certificate trust failure");
+      break;
+   case kSecTrustResultFatalTrustFailure:
+      bson_string_append (reason, "Certificate trust fatal failure");
+      break;
+   case kSecTrustResultInvalid:
+      bson_string_append (reason, "Certificate trust evaluation failure");
+      break;
+   default:
+      bson_string_append_printf (
+         reason, "Certificate trust failure #%d", (int) trust_result);
+      break;
+   }
+   bson_string_append (reason, ": ");
+
+   cfprops = SecTrustCopyProperties (trust);
+   /* This contains an array of dictionaries, each representing a cert in the
+    * chain. Append the first failure reason found. */
+   if (!cfprops) {
+      bson_string_append (reason, "Unable to retreive cause for trust failure");
+      goto done;
+   }
+
+   count = CFArrayGetCount (cfprops);
+   for (i = 0; i < count; ++i) {
+      const void *elem = NULL;
+      const void *reason_elem = NULL;
+      char *reason_str;
+      CFDictionaryRef dict;
+
+      elem = CFArrayGetValueAtIndex (cfprops, i);
+      if (CFGetTypeID (elem) != CFDictionaryGetTypeID ()) {
+         bson_string_append (reason, "Unable to parse cause for trust failure");
+         goto done;
+      }
+
+      dict = (CFDictionaryRef) elem;
+      reason_elem = CFDictionaryGetValue (dict, kSecPropertyTypeError);
+      if (!reason_elem) {
+         continue;
+      }
+      if (CFGetTypeID (reason_elem) != CFStringGetTypeID ()) {
+         bson_string_append (reason, "Unable to parse trust failure error");
+         goto done;
+      }
+      reason_str = _mongoc_cfstringref_to_cstring (reason_elem);
+      if (reason_str) {
+         bson_string_append (reason, reason_str);
+         bson_free (reason_str);
+         goto done;
+      } else {
+         bson_string_append (reason, "Unable to express trust failure error");
+         goto done;
+      }
+   }
+
+   bson_string_append (reason, "No trust failure reason available");
+done:
+   CFReleaseSafe (cfprops);
+   return bson_string_free (reason, false);
+}
+
+/* Returns a boolean indicating success. If false is returned, then an error is
+ * set.
+ */
+static bool
+_verify_peer (mongoc_stream_t *stream, bson_error_t *error)
+{
+   CFArrayRef policies = NULL;
+   SecTrustRef trust = NULL;
+   OSStatus status;
+   CFMutableArrayRef policies_mutable = NULL;
+   SecPolicyRef rev_policy = NULL;
+   SecTrustResultType trust_result;
+   mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
+   mongoc_stream_tls_secure_transport_t *secure_transport =
+      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   bool ret = false;
+
+   status = SSLCopyPeerTrust (secure_transport->ssl_ctx_ref, &trust);
+   if (status != noErr) {
+      _set_error_from_osstatus (
+         status, "Certificate validation errored", error);
+      goto fail;
+   }
+
+   status = SecTrustCopyPolicies (trust, &policies);
+
+   if (status != noErr) {
+      _set_error_from_osstatus (
+         status, "Certificate validation errored", error);
+      goto fail;
+   }
+
+   /* Add explicit OCSP revocation policy. */
+   policies_mutable = CFArrayCreateMutableCopy (NULL, 0, policies);
+
+   /* TODO: possibly disable endpoint checking by adding the flag
+    * kSecRevocationNetworkAccessDisabled once the option
+    * tlsDisableOCSPEndpointCheck is implemented. */
+   rev_policy = SecPolicyCreateRevocation (kSecRevocationOCSPMethod);
+   CFArrayAppendValue (policies_mutable, rev_policy);
+
+   status = SecTrustSetPolicies (trust, policies_mutable);
+
+   if (status != noErr) {
+      _set_error_from_osstatus (
+         status, "Certificate validation errored", error);
+      goto fail;
+   }
+
+   /* TODO: SecTrustEvaluate is blocking. When making Secure Transport's
+    * handshake is made non-blocking in CDRIVER-2885, this will need to be
+    * addressed. */
+   status = SecTrustEvaluate (trust, &trust_result);
+   if (status != noErr) {
+      _set_error_from_osstatus (
+         status, "Certificate validation errored", error);
+      goto fail;
+   }
+
+   if (trust_result != kSecTrustResultProceed &&
+       trust_result != kSecTrustResultUnspecified) {
+      char *reason = explain_trust_result (trust, trust_result);
+      bson_set_error (error,
+                      MONGOC_ERROR_STREAM,
+                      MONGOC_ERROR_STREAM_SOCKET,
+                      "TLS handshake failed (%s)",
+                      reason);
+      bson_free (reason);
+      goto fail;
+   }
+
+   ret = true;
+fail:
+   CFReleaseSafe (trust);
+   CFReleaseSafe (policies);
+   CFReleaseSafe (policies_mutable);
+   CFReleaseSafe (rev_policy);
+   return ret;
+}
+
 bool
 mongoc_stream_tls_secure_transport_handshake (mongoc_stream_t *stream,
                                               const char *host,
@@ -424,8 +602,6 @@ mongoc_stream_tls_secure_transport_handshake (mongoc_stream_t *stream,
                                               bson_error_t *error)
 {
    OSStatus ret = 0;
-   CFStringRef err;
-   char *err_str;
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
    mongoc_stream_tls_secure_transport_t *secure_transport =
       (mongoc_stream_tls_secure_transport_t *) tls->ctx;
@@ -434,9 +610,13 @@ mongoc_stream_tls_secure_transport_handshake (mongoc_stream_t *stream,
    BSON_ASSERT (secure_transport);
 
    ret = SSLHandshake (secure_transport->ssl_ctx_ref);
-   /* Weak certificate validation requested, eg: none */
 
    if (ret == errSSLServerAuthCompleted) {
+      if (!tls->ssl_opts.weak_cert_validation &&
+          !_verify_peer (stream, error)) {
+         *events = 0;
+         RETURN (false);
+      }
       ret = errSSLWouldBlock;
    }
 
@@ -448,17 +628,7 @@ mongoc_stream_tls_secure_transport_handshake (mongoc_stream_t *stream,
       *events = POLLIN | POLLOUT;
    } else {
       *events = 0;
-      err = SecCopyErrorMessageString (ret, NULL);
-      err_str = _mongoc_cfstringref_to_cstring (err);
-      bson_set_error (error,
-                      MONGOC_ERROR_STREAM,
-                      MONGOC_ERROR_STREAM_SOCKET,
-                      "TLS handshake failed: %s (%d)",
-                      err_str,
-                      ret);
-
-      bson_free (err_str);
-      CFRelease (err);
+      _set_error_from_osstatus (ret, "TLS handshake failed", error);
    }
 
    RETURN (false);
@@ -557,9 +727,11 @@ mongoc_stream_tls_secure_transport_new (mongoc_stream_t *base_stream,
    tls->base_stream = base_stream;
 
    if (client) {
+      /* This option has SSL_Handshake stop before it verifies peer cert. Set
+       * this since we verify peer cert manually later. */
       SSLSetSessionOption (secure_transport->ssl_ctx_ref,
                            kSSLSessionOptionBreakOnServerAuth,
-                           opt->weak_cert_validation);
+                           true);
    } else if (!opt->allow_invalid_hostname) {
       /* used only in mock_server_t tests */
       SSLSetClientSideAuthenticate (secure_transport->ssl_ctx_ref,
@@ -573,6 +745,16 @@ mongoc_stream_tls_secure_transport_new (mongoc_stream_t *base_stream,
 
 
    mongoc_counter_streams_active_inc ();
+
+   if (_mongoc_ssl_opts_disable_certificate_revocation_check (opt)) {
+      MONGOC_ERROR ("Setting tlsDisableCertificateRevocationCheck has no "
+                    "effect when built against Secure Transport");
+   }
+
+   if (_mongoc_ssl_opts_disable_ocsp_endpoint_check (opt)) {
+      MONGOC_ERROR ("Setting tlsDisableOCSPEndpointCheck has no effect when "
+                    "built against Secure Transport");
+   }
    RETURN ((mongoc_stream_t *) tls);
 }
 #endif /* MONGOC_ENABLE_SSL_SECURE_TRANSPORT */
