@@ -442,32 +442,39 @@ mongoc_uri_parse_host (mongoc_uri_t *uri, const char *host_and_port_in)
 }
 
 
-bool
-mongoc_uri_parse_srv (mongoc_uri_t *uri, const char *str)
+static bool
+mongoc_uri_parse_srv (mongoc_uri_t *uri, const char *str, bson_error_t *error)
 {
-   char *service;
-
    if (*str == '\0') {
+      MONGOC_URI_ERROR (error, "%s", "Missing service name in SRV URI");
       return false;
    }
 
-   service = bson_strdup (str);
-   mongoc_uri_do_unescape (&service);
-   if (!service) {
-      /* invalid */
-      return false;
-   }
+   {
+      char *service = bson_strdup (str);
+
+      mongoc_uri_do_unescape (&service);
+
+      if (!service || !valid_hostname (service) || count_dots (service) < 2) {
+         MONGOC_URI_ERROR (error, "%s", "Invalid service name in URI");
+         bson_free (service);
+         return false;
+      }
+
+      bson_strncpy (uri->srv, service, sizeof uri->srv);
 
-   if (!valid_hostname (service) || count_dots (service) < 2) {
       bson_free (service);
+   }
+
+   if (strchr (uri->srv, ',')) {
+      MONGOC_URI_ERROR (
+         error, "%s", "Multiple service names are prohibited in an SRV URI");
       return false;
    }
 
-   bson_strncpy (uri->srv, service, sizeof uri->srv);
-   bson_free (service);
-
-   if (strchr (uri->srv, ',') || strchr (uri->srv, ':')) {
-      /* prohibit port number or multiple service names */
+   if (strchr (uri->srv, ':')) {
+      MONGOC_URI_ERROR (
+         error, "%s", "Port numbers are prohibited in an SRV URI");
       return false;
    }
 
@@ -1543,8 +1550,7 @@ mongoc_uri_parse_before_slash (mongoc_uri_t *uri,
    }
 
    if (uri->is_srv) {
-      if (!mongoc_uri_parse_srv (uri, hosts)) {
-         MONGOC_URI_ERROR (error, "%s", "Invalid service name in URI");
+      if (!mongoc_uri_parse_srv (uri, hosts, error)) {
          goto error;
       }
    } else {
@@ -1912,7 +1918,7 @@ mongoc_uri_new_with_error (const char *uri_string, bson_error_t *error)
    mongoc_uri_t *uri;
    int32_t max_staleness_seconds;
 
-   uri = (mongoc_uri_t *) bson_malloc0 (sizeof *uri);
+   uri = BSON_ALIGNED_ALLOC0 (mongoc_uri_t);
    bson_init (&uri->raw);
    bson_init (&uri->options);
    bson_init (&uri->credentials);
@@ -2314,7 +2320,7 @@ mongoc_uri_copy (const mongoc_uri_t *uri)
 
    BSON_ASSERT (uri);
 
-   copy = (mongoc_uri_t *) bson_malloc0 (sizeof (*copy));
+   copy = BSON_ALIGNED_ALLOC0 (mongoc_uri_t);
 
    copy->str = bson_strdup (uri->str);
    copy->is_srv = uri->is_srv;
