@@ -69,6 +69,13 @@ special_placeholder (bson_matcher_t *matcher,
                      const char *path,
                      bson_error_t *error)
 {
+   BSON_UNUSED (matcher);
+   BSON_UNUSED (assertion);
+   BSON_UNUSED (actual);
+   BSON_UNUSED (ctx);
+   BSON_UNUSED (path);
+   BSON_UNUSED (error);
+
    /* Nothing to do (not an operator, just a reserved key value). The meaning
     * and corresponding behavior of $$placeholder depends on context. */
    return true;
@@ -87,6 +94,9 @@ special_exists (bson_matcher_t *matcher,
    bson_iter_t iter;
    bool should_exist;
 
+   BSON_UNUSED (matcher);
+   BSON_UNUSED (ctx);
+
    bson_iter_init (&iter, assertion);
    BSON_ASSERT (bson_iter_next (&iter));
 
@@ -122,6 +132,9 @@ special_type (bson_matcher_t *matcher,
    bool ret = false;
    bson_iter_t iter;
 
+   BSON_UNUSED (matcher);
+   BSON_UNUSED (ctx);
+
    bson_iter_init (&iter, assertion);
    BSON_ASSERT (bson_iter_next (&iter));
 
@@ -189,6 +202,8 @@ special_unset_or_matches (bson_matcher_t *matcher,
    bson_iter_t iter;
    bson_val_t *expected = NULL;
 
+   BSON_UNUSED (ctx);
+
    bson_iter_init (&iter, assertion);
    BSON_ASSERT (bson_iter_next (&iter));
    expected = bson_val_from_iter (&iter);
@@ -226,6 +241,9 @@ special_matches_hex_bytes (bson_matcher_t *matcher,
    char *actual_bytes_string = NULL;
    bson_iter_t iter;
 
+   BSON_UNUSED (matcher);
+   BSON_UNUSED (ctx);
+
    bson_iter_init (&iter, assertion);
    BSON_ASSERT (bson_iter_next (&iter));
 
