@@ -1682,6 +1682,8 @@ find_key (void *current, void *key)
 static void
 key_dtor (void *item, void *ctx)
 {
+   BSON_UNUSED (item);
+   BSON_UNUSED (ctx);
    /* mongoc_set_t requires a dtor, there's nothing to destroy */
 }
 
