@@ -25,6 +25,7 @@
 #include "mongoc/mongoc-client-private.h"
 #include "mongoc/mongoc-uri-private.h"
 #include "mongoc/mongoc-util-private.h"
+#include "mongoc/mongoc-linux-distro-scanner-private.h"
 
 #include "TestSuite.h"
 #include "test-conveniences.h"
@@ -85,6 +86,8 @@ extern void
 test_writer_install (TestSuite *suite);
 extern void
 test_b64_install (TestSuite *suite);
+extern void
+test_bson_cmp_install (TestSuite *suite);
 
 /* libmongoc */
 
@@ -1158,6 +1161,7 @@ call_hello_with_host_and_port (const char *host_and_port, bson_t *reply)
    }
 
    client = test_framework_client_new_from_uri (uri, NULL);
+
 #ifdef MONGOC_ENABLE_SSL
    test_framework_set_ssl_opts (client);
 #endif
@@ -1712,6 +1716,37 @@ test_framework_new_default_client ()
    return client;
 }
 
+/*
+ *--------------------------------------------------------------------------
+ *
+ * test_framework_client_new_no_server_api --
+ *
+ *       Get a client connected to the test MongoDB topology, with no server
+ *       API version set.
+ *
+ * Returns:
+ *       A client you must mongoc_client_destroy.
+ *
+ * Side effects:
+ *       None.
+ *
+ *--------------------------------------------------------------------------
+ */
+mongoc_client_t *
+test_framework_client_new_no_server_api ()
+{
+   mongoc_uri_t *uri = test_framework_get_uri ();
+   mongoc_client_t *client = mongoc_client_new_from_uri (uri);
+
+   BSON_ASSERT (client);
+   test_framework_set_ssl_opts (client);
+
+   mongoc_uri_destroy (uri);
+
+   return client;
+}
+
+
 mongoc_server_api_t *
 test_framework_get_default_server_api (void)
 {
@@ -2198,6 +2233,31 @@ test_framework_skip_if_offline (void)
 }
 
 
+int
+test_framework_skip_if_rhel8_zseries (void)
+{
+   /* CDRIVER-3923: It appears that when running on RHEL8 on zSeries the
+    * /server_discovery_and_monitoring/monitoring/heartbeat/pooled/dns test
+    * fails.  The best guess is that calling getaddrinfo() on that platform
+    * blocks for 5 seconds, while the test expects a server selection error
+    * after 3000 ms, or 3 seconds.  Skip the test when executing on RHEL8 on
+    * zSeries. */
+#ifdef __s390x__
+   char *name;
+   char *version;
+   _mongoc_linux_distro_scanner_get_distro (&name, &version);
+   bool rhel = strcmp (name, "Red Hat Enterprise Linux") == 0;
+   bool vers8 = version[0] == '8';
+   int skip = (rhel && vers8) ? 0 : 1;
+   bson_free (name);
+   bson_free (version);
+   return skip;
+#else
+   return 1;
+#endif
+}
+
+
 int
 test_framework_skip_if_slow (void)
 {
@@ -2334,14 +2394,12 @@ _parse_server_version (const bson_t *buildinfo)
 }
 
 server_version_t
-test_framework_get_server_version (void)
+test_framework_get_server_version_with_client (mongoc_client_t *client)
 {
-   mongoc_client_t *client;
    bson_t reply;
    bson_error_t error;
    server_version_t ret = 0;
 
-   client = test_framework_new_default_client ();
    ASSERT_OR_PRINT (
       mongoc_client_command_simple (
          client, "admin", tmp_bson ("{'buildinfo': 1}"), NULL, &reply, &error),
@@ -2350,6 +2408,21 @@ test_framework_get_server_version (void)
    ret = _parse_server_version (&reply);
 
    bson_destroy (&reply);
+
+   return ret;
+}
+
+server_version_t
+test_framework_get_server_version (void)
+{
+   mongoc_client_t *client;
+
+   server_version_t ret = 0;
+
+   client = test_framework_new_default_client ();
+
+   ret = test_framework_get_server_version_with_client (client);
+
    mongoc_client_destroy (client);
 
    return ret;
@@ -2531,6 +2604,8 @@ WIRE_VERSION_CHECKS (9)
 WIRE_VERSION_CHECKS (13)
 /* wire version 14 begins with the 5.1 prerelease. */
 WIRE_VERSION_CHECKS (14)
+/* wire version 17 begins with the 6.0 release. */
+WIRE_VERSION_CHECKS (17)
 
 int
 test_framework_skip_if_no_dual_ip_hostname (void)
@@ -2868,6 +2943,7 @@ main (int argc, char *argv[])
    test_value_install (&suite);
    test_writer_install (&suite);
    test_b64_install (&suite);
+   test_bson_cmp_install (&suite);
 
    /* libmongoc */
 
