@@ -6,6 +6,7 @@
 #include "mock_server/future.h"
 #include "mock_server/future-functions.h"
 #include "test-conveniences.h"
+#include "test-libmongoc.h"
 
 static void
 _test_query_flag (mongoc_query_flags_t flag, bson_t *opt)
@@ -19,9 +20,10 @@ _test_query_flag (mongoc_query_flags_t flag, bson_t *opt)
    request_t *request;
    const bson_t *doc;
 
-   server = mock_server_with_autoismaster (WIRE_VERSION_MAX);
+   server = mock_server_with_auto_hello (WIRE_VERSION_MAX);
    mock_server_run (server);
-   client = mongoc_client_new_from_uri (mock_server_get_uri (server));
+   client =
+      test_framework_client_new_from_uri (mock_server_get_uri (server), NULL);
    collection = mongoc_client_get_collection (client, "db", "collection");
    cursor = mongoc_collection_aggregate (
       collection, flag, tmp_bson ("{'pipeline': []}"), opt, NULL);
