@@ -599,6 +599,8 @@ test_topology_discovery (void *ctx)
    bson_error_t error;
    bool r;
 
+   BSON_UNUSED (ctx);
+
    host_and_port = test_framework_get_host_and_port ();
    replset_name = test_framework_replset_name ();
    uri_str = test_framework_get_uri_str ();
@@ -662,6 +664,8 @@ test_direct_connection (void *ctx)
    bson_error_t error;
    bool r;
 
+   BSON_UNUSED (ctx);
+
    host_and_port = test_framework_get_host_and_port ();
    replset_name = test_framework_replset_name ();
    uri_str = test_framework_get_uri_str ();
@@ -727,6 +731,8 @@ test_existing_behavior (void *ctx)
    bson_error_t error;
    bool r;
 
+   BSON_UNUSED (ctx);
+
    host_and_port = test_framework_get_host_and_port ();
    replset_name = test_framework_replset_name ();
    uri_str = test_framework_get_uri_str ();
@@ -822,6 +828,8 @@ test_prose_rtt (void *unused)
    bool satisfied;
    int64_t rtt = 0;
 
+   BSON_UNUSED (unused);
+
    uri = test_framework_get_uri ();
    mongoc_uri_set_option_as_utf8 (uri, MONGOC_URI_APPNAME, "streamingRttTest");
    mongoc_uri_set_option_as_int32 (uri, MONGOC_URI_HEARTBEATFREQUENCYMS, 500);
