@@ -32,6 +32,8 @@ test_topology_scanner_helper (uint32_t id,
    int *finished = (int *) data;
    uint32_t max_wire_version;
 
+   BSON_UNUSED (rtt_msec);
+
    if (error->code) {
       fprintf (stderr, "scanner error: %s\n", error->message);
       abort ();
@@ -183,7 +185,7 @@ test_topology_scanner_discovery (void)
    secondary_pref = mongoc_read_prefs_new (MONGOC_READ_SECONDARY_PREFERRED);
 
    future = future_topology_select (
-      client->topology, MONGOC_SS_READ, secondary_pref, &error);
+      client->topology, MONGOC_SS_READ, secondary_pref, NULL, &error);
 
    /* a single scan discovers *and* checks the secondary */
    request = mock_server_receives_any_hello (primary);
@@ -263,7 +265,7 @@ test_topology_scanner_oscillate (void)
 
    BSON_ASSERT (!scanner->async->ncmds);
    future = future_topology_select (
-      client->topology, MONGOC_SS_READ, primary_pref, &error);
+      client->topology, MONGOC_SS_READ, primary_pref, NULL, &error);
 
    /* a single scan discovers servers 0 and 1 */
    request = mock_server_receives_any_hello (server0);
@@ -472,6 +474,11 @@ _test_topology_scanner_dns_helper (uint32_t id,
                                    const bson_error_t *error /* IN */)
 {
    dns_testcase_t *testcase = (dns_testcase_t *) data;
+
+   BSON_UNUSED (id);
+   BSON_UNUSED (bson);
+   BSON_UNUSED (rtt_msec);
+
    if (testcase->should_succeed) {
       ASSERT_OR_PRINT (!error->code, (*error));
    } else {
@@ -577,6 +584,11 @@ _retired_fails_to_initiate_cb (uint32_t id,
                                void *data,
                                const bson_error_t *error /* IN */)
 {
+   BSON_UNUSED (id);
+   BSON_UNUSED (bson);
+   BSON_UNUSED (rtt_msec);
+   BSON_UNUSED (data);
+   BSON_UNUSED (error);
    /* this should never get called. */
    BSON_ASSERT (false);
 }
@@ -584,6 +596,8 @@ _retired_fails_to_initiate_cb (uint32_t id,
 static mongoc_stream_t *
 null_initiator (mongoc_async_cmd_t *acmd)
 {
+   BSON_UNUSED (acmd);
+
    return NULL;
 }
 
@@ -702,12 +716,16 @@ _test_topology_scanner_does_not_renegotiate (bool pooled)
 static void
 test_topology_scanner_does_not_renegotiate_single (void *ctx)
 {
+   BSON_UNUSED (ctx);
+
    _test_topology_scanner_does_not_renegotiate (false);
 }
 
 static void
 test_topology_scanner_does_not_renegotiate_pooled (void *ctx)
 {
+   BSON_UNUSED (ctx);
+
    _test_topology_scanner_does_not_renegotiate (true);
 }
 
