@@ -2440,6 +2440,8 @@ assert_session_dirty_helper (test_t *test,
 {
    bool ret = false;
 
+   BSON_UNUSED (test);
+
    if (!op->session) {
       test_set_error (error, "%s", "session unset");
       goto done;
@@ -2690,6 +2692,8 @@ operation_assert_session_transaction_state (test_t *test,
    const char *actual;
    mongoc_transaction_state_t state;
 
+   BSON_UNUSED (test);
+
    bp = bson_parser_new ();
    bson_parser_utf8 (bp, "state", &expected);
    if (!bson_parser_parse (bp, op->arguments, error)) {
@@ -2941,6 +2945,9 @@ with_transaction_cb (mongoc_client_session_t *session,
    bson_iter_t iter;
    txn_ctx_t *tctx = NULL;
 
+   BSON_UNUSED (session);
+   BSON_UNUSED (reply);
+
    tctx = (txn_ctx_t *) ctx;
 
    BSON_FOREACH (tctx->ops, iter)
@@ -3028,6 +3035,8 @@ assert_session_pinned (test_t *test,
    bool ret = false;
    bool actual_pinned = false;
 
+   BSON_UNUSED (test);
+
    if (!op->session) {
       test_set_error (error, "%s", "expected session to be set");
       goto done;
@@ -3075,6 +3084,9 @@ operation_loop (test_t *test,
                 result_t *result,
                 bson_error_t *error)
 {
+   BSON_UNUSED (test);
+   BSON_UNUSED (op);
+   BSON_UNUSED (result);
    /* TODO: CDRIVER-3867 Comprehensive Atlas Testing */
    test_set_error (error, "Loop operation not implemented");
    return false;
@@ -3086,6 +3098,9 @@ operation_assert_number_connections_checked_out (test_t *test,
                                                  result_t *result,
                                                  bson_error_t *error)
 {
+   BSON_UNUSED (test);
+   BSON_UNUSED (op);
+   BSON_UNUSED (error);
    /* "This operation only applies to drivers that implement connection pooling
     * and should be skipped for drivers that do not."
     * TODO: (CDRIVER-3525) add this assertion when CMAP is implemented. */
